local addonName, Namespace = ...

local panel = CreateFrame("Frame")
panel.name = "Bagmeter";
InterfaceOptions_AddCategory(panel);

panel:SetScript("OnShow", function()
	total:SetChecked(Bagmeter_Total==1);
	subcount:SetChecked(Bagmeter_Subcount==1);
	subTotal:SetChecked(Bagmeter_Subtotal==1);
	useColors:SetChecked(Bagmeter_Color==1);
	spaceToggle:SetChecked(Bagmeter_Used==0);
	end)

total = CreateFrame("CheckButton", "BM_Option_Total", panel, "InterfaceOptionsBaseCheckButtonTemplate");
total:SetPoint("TOPLEFT",20, -20);
total.text:SetText("Show Total free/used space.");
total:SetScript("OnClick", function(self, button)
		if (self:GetChecked()) then
			Bagmeter_CommandHandler("total on");
		else
			Bagmeter_CommandHandler("total off");
		end							
	end)
total:SetScript("OnLoad", function()
		self:SetChecked(NS.Bagmeter_Total);
	end)

subcount = CreateFrame("CheckButton", "BM_Option_Subcount", total, "InterfaceOptionsBaseCheckButtonTemplate");
subcount:SetPoint("TOPLEFT", 0, -20);
subcount.text:SetText("Show individual bag data.");
subcount:SetScript("OnClick", function(self, button)
		if (subcount:GetChecked()) then
			Bagmeter_CommandHandler("subcount on");
		else
			Bagmeter_CommandHandler("subcount off");
		end								
	end)
subcount:SetScript("OnLoad", function()
	self:SetChecked(NS.Bagmeter_Subcount);
end)

subTotal = CreateFrame("CheckButton", "BM_Option_Subtotal", subcount, "InterfaceOptionsBaseCheckButtonTemplate");
subTotal:SetPoint("TOPLEFT", 0, -20);
subTotal.text:SetText("Show total space per bag.");
subTotal:SetScript("OnClick", function(self, button)
		if (subTotal:GetChecked()) then
			Bagmeter_CommandHandler("subtotal on");
		else
			Bagmeter_CommandHandler("subtotal off");
		end								
	end)
	subcount:SetScript("OnLoad", function()	
			self:SetChecked(NS.Bagmeter_Subtotal);
	end)


useColors = CreateFrame("CheckButton", "BM_Option_Usecolors", subTotal, "InterfaceOptionsBaseCheckButtonTemplate");
useColors:SetPoint("TOPLEFT", 0, -20);
useColors.text:SetText("Use colors to represent relative available space.");
useColors:SetScript("OnLoad", function()
		self:SetChecked(NS.Bagmeter_Color);
	end)
useColors:SetScript("OnClick", function(self, button)
		if (useColors:GetChecked()) then
			Bagmeter_CommandHandler("color on");
		else
			Bagmeter_CommandHandler("color off");
		end								
	end)

spaceToggle = CreateFrame("CheckButton", "BM_Option_Spacetoggle", useColors, "InterfaceOptionsBaseCheckButtonTemplate");
spaceToggle:SetPoint("TOPLEFT", 0, -20);
spaceToggle.text:SetText("Show available bag space.  (Uncheck to show used space)");
spaceToggle:SetScript("OnClick", function(self, button)
		if (spaceToggle:GetChecked()) then
			Bagmeter_CommandHandler("show free");
		else
			Bagmeter_CommandHandler("show used");
		end								
	end)	

---------------------------------------------------
-- Font Size Slider
---------------------------------------------------

fontSlider = CreateFrame("Slider", nil, spaceToggle, "OptionsSliderTemplate");
fontSlider:SetPoint("TOPLEFT", 0, -60);
fontSlider:SetMinMaxValues(4, 18);
fontSlider:SetValue(Bagmeter_FontSize);
fontSlider:SetValueStep(1);
fontSlider:SetObeyStepOnDrag(true);
fontSlider:SetScript("OnValueChanged", function(self, button)
		Bagmeter_FontSize = fontSlider:GetValue();
		Bagmeter_OnEvent(1);
		fSliderString:SetText("Text Font Size: " .. Bagmeter_FontSize);
	end)
	
fSliderString = fontSlider:CreateFontString(nil, "OVERLAY", "GameFontNormal");
fSliderString:SetText("Text Font Size: " .. Bagmeter_FontSize);
fSliderString:SetPoint("LEFT", 0, 20);
 

---------------------------------------------------
-- Font Horizontal Alignment
---------------------------------------------------

fontH = CreateFrame("Frame", "FontHorizontal", fontSlider, "UIDropDownMenuTemplate");
fontH:SetPoint("TOPLEFT", 150, -30);
fontH:SetPoint("Center");
UIDropDownMenu_SetWidth(fontH, 100);
UIDropDownMenu_SetText(fontH, "");

local fhString = fontH:CreateFontString(nil, "OVERLAY", "GameFontNormal");
fhString:SetText("Horizontal Alignment: ");
fhString:SetPoint("LEFT", -150, 0);
 

UIDropDownMenu_Initialize(fontH, function(self, level, menuList)
	local info = UIDropDownMenu_CreateInfo();
	info.func = fontH_Menu_OnClick;
	info.text = "LEFT";
	info.checked = (Bagmeter_Horizontal == "LEFT");
	info.hasArrow = false;
	UIDropDownMenu_AddButton(info);

	info.text = "RIGHT";
	info.checked = (Bagmeter_Horizontal == "RIGHT");
	info.hasArrow = false;
	UIDropDownMenu_AddButton(info);

	info.text = "CENTER";
	info.checked = (Bagmeter_Horizontal == "CENTER");
	info.hasArrow = false;
	UIDropDownMenu_AddButton(info);
end);

function fontH:SetValue(newValue)
		Bagmeter_Horizontal = newValue;
		Bagmeter_OnEvent(1);
end

function fontH_Menu_OnClick(self, arg1, arg2, checked)
	Bagmeter_Horizontal = self.value;
	UIDropDownMenu_SetText(fontH, Bagmeter_Horizontal);
	Bagmeter_OnEvent(1);
end

---------------------------------------------------
-- Font Vertical Alignment
---------------------------------------------------

fontV = CreateFrame("Frame", "FontVertical", fontH, "UIDropDownMenuTemplate");
fontV:SetPoint("TOPLEFT", 0, -30);
fontV:SetPoint("Center");
UIDropDownMenu_SetWidth(fontV, 100);
UIDropDownMenu_SetText(fontV, "");

local fvString = fontV:CreateFontString(nil, "OVERLAY", "GameFontNormal");
fvString:SetText("Vertical Alignment: ");
fvString:SetPoint("LEFT", -150, 0);
 

UIDropDownMenu_Initialize(fontV, function(self, level, menuList)
	local info = UIDropDownMenu_CreateInfo();
	info.func = fontV_Menu_OnClick;
	info.text = "TOP";
	info.checked = (Bagmeter_Vertical == "TOP");
	info.hasArrow = false;
	UIDropDownMenu_AddButton(info);

	info.text = "MIDDLE";
	info.checked = (Bagmeter_Vertical == "MIDDLE");
	info.hasArrow = false;
	UIDropDownMenu_AddButton(info);

	info.text = "BOTTOM";
	info.checked = (Bagmeter_Vertical == "BOTTOM");
	info.hasArrow = false;
	UIDropDownMenu_AddButton(info);
end);

function fontV:SetValue(newValue)
		Bagmeter_Vertical = newValue;
		UIDropDownMenu_SetText(fontV, Bagmeter_Vertical);
		Bagmeter_OnEvent(1);
end

function fontV_Menu_OnClick(self, arg1, arg2, checked)
	Bagmeter_Vertical = self.value;
	UIDropDownMenu_SetText(fontV, Bagmeter_Vertical);
	Bagmeter_OnEvent(1);
end

---------------------------------------------------
-- Bag Offset Slider
---------------------------------------------------

bagSlider = CreateFrame("Slider", nil, fontV, "OptionsSliderTemplate");
bagSlider:SetPoint("TOPLEFT", -150, -60);
bagSlider:SetMinMaxValues(0, 20);
bagSlider:SetValue(Bagmeter_Offset);
bagSlider:SetValueStep(1);
bagSlider:SetObeyStepOnDrag(true);
bagSlider:SetScript("OnValueChanged", function(self, button)
		Bagmeter_Offset = bagSlider:GetValue();
		Bagmeter_OnEvent(1);
		bagSliderString:SetText("Bag Offset: " .. Bagmeter_Offset);
	end)
	
bagSliderString = bagSlider:CreateFontString(nil, "OVERLAY", "GameFontNormal");
bagSliderString:SetText("Bag Offset: " .. Bagmeter_Offset);
bagSliderString:SetPoint("Left", 0, 20);
